"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const socket_1 = require("./socket");
class Factory {
    constructor(server, senderDomain) {
        this.server = server;
        this.senderDomain = senderDomain;
    }
    async create() {
        const connection = await socket_1.default.connect(this.server);
        const response = await connection.execute(`HELO ${this.senderDomain}`);
        if (response.code !== 250) {
            throw new Error(`Server did not accept sender domain: ${this.senderDomain}`);
        }
        return connection;
    }
    async destroy(connection, error) {
        try {
            const response = await connection.execute('QUIT');
            if (response.code !== 221) {
                throw new Error('Server did not respond to "QUIT" command');
            }
        }
        finally {
            await connection.end();
        }
    }
    async recycle(connection, error) {
        if (error) {
            try {
                await this.destroy(connection, error);
            }
            catch (_a) { }
            return this.create();
        }
        const response = await connection.execute('RSET');
        if (response.code !== 250) {
            throw new Error(`Server did not accept RSET command`);
        }
        return connection;
    }
}
exports.default = Factory;
